@@ -1,16 +1,13 @@
 # -*- coding: utf-8 -*-
 #
 #  -------------------------------------------------------------------------
-#  pyCGNS - Python package for CFD General Notation System - 
-#  See license.txt file in the root directory of this Python module source  
+#  pyCGNS - Python package for CFD General Notation System -
+#  See license.txt file in the root directory of this Python module source
 #  -------------------------------------------------------------------------
 #
-from __future__ import unicode_literals
-from __future__ import print_function
-from builtins import (str, bytes, range, dict)
 
-from CGNS.APP.lib.queries import asQuery
-from CGNS.APP.lib.queries import runQuery
+from ..APP.lib.queries import asQuery
+from ..APP.lib.queries import runQuery
 
 
 @asQuery
@@ -51,12 +48,12 @@ def nodeTokenSearch(C):
         return C.PATH
 
 
-FILE = 'HYB/vbv-part32_comp_period_links_dom_32_SUB.hdf'
-ARGS = ['GridLocation']
+FILE = "HYB/vbv-part32_comp_period_links_dom_32_SUB.hdf"
+ARGS = ["GridLocation"]
 
 # -----------------------------------------------------------------
-import CGNS.MAP as CGM
+from .. import MAP as CGM
 
 (t, l, p) = CGM.load(FILE)
-print(runQuery(t, l, p, nodeNameSearch, ['GridLocation']))
-print(runQuery(t, l, p, nodeTokenSearch, ['Zone']))
+print(runQuery(t, l, p, nodeNameSearch, ["GridLocation"]))
+print(runQuery(t, l, p, nodeTokenSearch, ["Zone"]))
